Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.RoleBinding) predicate.RoleBinding
- func CreatedAt(v time.Time) predicate.RoleBinding
- func CreatedAtEQ(v time.Time) predicate.RoleBinding
- func CreatedAtGT(v time.Time) predicate.RoleBinding
- func CreatedAtGTE(v time.Time) predicate.RoleBinding
- func CreatedAtIn(vs ...time.Time) predicate.RoleBinding
- func CreatedAtLT(v time.Time) predicate.RoleBinding
- func CreatedAtLTE(v time.Time) predicate.RoleBinding
- func CreatedAtNEQ(v time.Time) predicate.RoleBinding
- func CreatedAtNotIn(vs ...time.Time) predicate.RoleBinding
- func ExpiresAt(v time.Time) predicate.RoleBinding
- func ExpiresAtEQ(v time.Time) predicate.RoleBinding
- func ExpiresAtGT(v time.Time) predicate.RoleBinding
- func ExpiresAtGTE(v time.Time) predicate.RoleBinding
- func ExpiresAtIn(vs ...time.Time) predicate.RoleBinding
- func ExpiresAtIsNil() predicate.RoleBinding
- func ExpiresAtLT(v time.Time) predicate.RoleBinding
- func ExpiresAtLTE(v time.Time) predicate.RoleBinding
- func ExpiresAtNEQ(v time.Time) predicate.RoleBinding
- func ExpiresAtNotIn(vs ...time.Time) predicate.RoleBinding
- func ExpiresAtNotNil() predicate.RoleBinding
- func GrantedBy(v string) predicate.RoleBinding
- func GrantedByContains(v string) predicate.RoleBinding
- func GrantedByContainsFold(v string) predicate.RoleBinding
- func GrantedByEQ(v string) predicate.RoleBinding
- func GrantedByEqualFold(v string) predicate.RoleBinding
- func GrantedByGT(v string) predicate.RoleBinding
- func GrantedByGTE(v string) predicate.RoleBinding
- func GrantedByHasPrefix(v string) predicate.RoleBinding
- func GrantedByHasSuffix(v string) predicate.RoleBinding
- func GrantedByIn(vs ...string) predicate.RoleBinding
- func GrantedByLT(v string) predicate.RoleBinding
- func GrantedByLTE(v string) predicate.RoleBinding
- func GrantedByNEQ(v string) predicate.RoleBinding
- func GrantedByNotIn(vs ...string) predicate.RoleBinding
- func ID(id uuid.UUID) predicate.RoleBinding
- func IDEQ(id uuid.UUID) predicate.RoleBinding
- func IDGT(id uuid.UUID) predicate.RoleBinding
- func IDGTE(id uuid.UUID) predicate.RoleBinding
- func IDIn(ids ...uuid.UUID) predicate.RoleBinding
- func IDLT(id uuid.UUID) predicate.RoleBinding
- func IDLTE(id uuid.UUID) predicate.RoleBinding
- func IDNEQ(id uuid.UUID) predicate.RoleBinding
- func IDNotIn(ids ...uuid.UUID) predicate.RoleBinding
- func Not(p predicate.RoleBinding) predicate.RoleBinding
- func Or(predicates ...predicate.RoleBinding) predicate.RoleBinding
- func RoleKey(v string) predicate.RoleBinding
- func RoleKeyContains(v string) predicate.RoleBinding
- func RoleKeyContainsFold(v string) predicate.RoleBinding
- func RoleKeyEQ(v string) predicate.RoleBinding
- func RoleKeyEqualFold(v string) predicate.RoleBinding
- func RoleKeyGT(v string) predicate.RoleBinding
- func RoleKeyGTE(v string) predicate.RoleBinding
- func RoleKeyHasPrefix(v string) predicate.RoleBinding
- func RoleKeyHasSuffix(v string) predicate.RoleBinding
- func RoleKeyIn(vs ...string) predicate.RoleBinding
- func RoleKeyLT(v string) predicate.RoleBinding
- func RoleKeyLTE(v string) predicate.RoleBinding
- func RoleKeyNEQ(v string) predicate.RoleBinding
- func RoleKeyNotIn(vs ...string) predicate.RoleBinding
- func ScopeID(v string) predicate.RoleBinding
- func ScopeIDContains(v string) predicate.RoleBinding
- func ScopeIDContainsFold(v string) predicate.RoleBinding
- func ScopeIDEQ(v string) predicate.RoleBinding
- func ScopeIDEqualFold(v string) predicate.RoleBinding
- func ScopeIDGT(v string) predicate.RoleBinding
- func ScopeIDGTE(v string) predicate.RoleBinding
- func ScopeIDHasPrefix(v string) predicate.RoleBinding
- func ScopeIDHasSuffix(v string) predicate.RoleBinding
- func ScopeIDIn(vs ...string) predicate.RoleBinding
- func ScopeIDLT(v string) predicate.RoleBinding
- func ScopeIDLTE(v string) predicate.RoleBinding
- func ScopeIDNEQ(v string) predicate.RoleBinding
- func ScopeIDNotIn(vs ...string) predicate.RoleBinding
- func ScopeKindEQ(v ScopeKind) predicate.RoleBinding
- func ScopeKindIn(vs ...ScopeKind) predicate.RoleBinding
- func ScopeKindNEQ(v ScopeKind) predicate.RoleBinding
- func ScopeKindNotIn(vs ...ScopeKind) predicate.RoleBinding
- func ScopeKindValidator(sk ScopeKind) error
- func SubjectKey(v string) predicate.RoleBinding
- func SubjectKeyContains(v string) predicate.RoleBinding
- func SubjectKeyContainsFold(v string) predicate.RoleBinding
- func SubjectKeyEQ(v string) predicate.RoleBinding
- func SubjectKeyEqualFold(v string) predicate.RoleBinding
- func SubjectKeyGT(v string) predicate.RoleBinding
- func SubjectKeyGTE(v string) predicate.RoleBinding
- func SubjectKeyHasPrefix(v string) predicate.RoleBinding
- func SubjectKeyHasSuffix(v string) predicate.RoleBinding
- func SubjectKeyIn(vs ...string) predicate.RoleBinding
- func SubjectKeyLT(v string) predicate.RoleBinding
- func SubjectKeyLTE(v string) predicate.RoleBinding
- func SubjectKeyNEQ(v string) predicate.RoleBinding
- func SubjectKeyNotIn(vs ...string) predicate.RoleBinding
- func SubjectKindEQ(v SubjectKind) predicate.RoleBinding
- func SubjectKindIn(vs ...SubjectKind) predicate.RoleBinding
- func SubjectKindNEQ(v SubjectKind) predicate.RoleBinding
- func SubjectKindNotIn(vs ...SubjectKind) predicate.RoleBinding
- func SubjectKindValidator(sk SubjectKind) error
- func UpdatedAt(v time.Time) predicate.RoleBinding
- func UpdatedAtEQ(v time.Time) predicate.RoleBinding
- func UpdatedAtGT(v time.Time) predicate.RoleBinding
- func UpdatedAtGTE(v time.Time) predicate.RoleBinding
- func UpdatedAtIn(vs ...time.Time) predicate.RoleBinding
- func UpdatedAtLT(v time.Time) predicate.RoleBinding
- func UpdatedAtLTE(v time.Time) predicate.RoleBinding
- func UpdatedAtNEQ(v time.Time) predicate.RoleBinding
- func UpdatedAtNotIn(vs ...time.Time) predicate.RoleBinding
- func ValidColumn(column string) bool
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByExpiresAt(opts ...sql.OrderTermOption) OrderOption
- func ByGrantedBy(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByRoleKey(opts ...sql.OrderTermOption) OrderOption
- func ByScopeID(opts ...sql.OrderTermOption) OrderOption
- func ByScopeKind(opts ...sql.OrderTermOption) OrderOption
- func BySubjectKey(opts ...sql.OrderTermOption) OrderOption
- func BySubjectKind(opts ...sql.OrderTermOption) OrderOption
- func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
- type ScopeKind
- type SubjectKind
Constants ¶
const ( // Label holds the string label denoting the rolebinding type in the database. Label = "role_binding" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldScopeKind holds the string denoting the scope_kind field in the database. FieldScopeKind = "scope_kind" // FieldScopeID holds the string denoting the scope_id field in the database. FieldScopeID = "scope_id" // FieldSubjectKind holds the string denoting the subject_kind field in the database. FieldSubjectKind = "subject_kind" // FieldSubjectKey holds the string denoting the subject_key field in the database. FieldSubjectKey = "subject_key" // FieldRoleKey holds the string denoting the role_key field in the database. FieldRoleKey = "role_key" // FieldGrantedBy holds the string denoting the granted_by field in the database. FieldGrantedBy = "granted_by" // FieldExpiresAt holds the string denoting the expires_at field in the database. FieldExpiresAt = "expires_at" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldUpdatedAt holds the string denoting the updated_at field in the database. FieldUpdatedAt = "updated_at" // Table holds the table name of the rolebinding in the database. Table = "role_bindings" )
Variables ¶
var ( // DefaultScopeID holds the default value on creation for the "scope_id" field. DefaultScopeID string // SubjectKeyValidator is a validator for the "subject_key" field. It is called by the builders before save. SubjectKeyValidator func(string) error // RoleKeyValidator is a validator for the "role_key" field. It is called by the builders before save. RoleKeyValidator func(string) error // DefaultGrantedBy holds the default value on creation for the "granted_by" field. DefaultGrantedBy string // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultUpdatedAt holds the default value on creation for the "updated_at" field. DefaultUpdatedAt func() time.Time // UpdateDefaultUpdatedAt holds the default value on update for the "updated_at" field. UpdateDefaultUpdatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldScopeKind, FieldScopeID, FieldSubjectKind, FieldSubjectKey, FieldRoleKey, FieldGrantedBy, FieldExpiresAt, FieldCreatedAt, FieldUpdatedAt, }
Columns holds all SQL columns for rolebinding fields.
Functions ¶
func And ¶
func And(predicates ...predicate.RoleBinding) predicate.RoleBinding
And groups predicates with the AND operator between them.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.RoleBinding
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.RoleBinding
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.RoleBinding
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.RoleBinding
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.RoleBinding
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.RoleBinding
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.RoleBinding
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.RoleBinding
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.RoleBinding
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func ExpiresAt ¶
func ExpiresAt(v time.Time) predicate.RoleBinding
ExpiresAt applies equality check predicate on the "expires_at" field. It's identical to ExpiresAtEQ.
func ExpiresAtEQ ¶
func ExpiresAtEQ(v time.Time) predicate.RoleBinding
ExpiresAtEQ applies the EQ predicate on the "expires_at" field.
func ExpiresAtGT ¶
func ExpiresAtGT(v time.Time) predicate.RoleBinding
ExpiresAtGT applies the GT predicate on the "expires_at" field.
func ExpiresAtGTE ¶
func ExpiresAtGTE(v time.Time) predicate.RoleBinding
ExpiresAtGTE applies the GTE predicate on the "expires_at" field.
func ExpiresAtIn ¶
func ExpiresAtIn(vs ...time.Time) predicate.RoleBinding
ExpiresAtIn applies the In predicate on the "expires_at" field.
func ExpiresAtIsNil ¶
func ExpiresAtIsNil() predicate.RoleBinding
ExpiresAtIsNil applies the IsNil predicate on the "expires_at" field.
func ExpiresAtLT ¶
func ExpiresAtLT(v time.Time) predicate.RoleBinding
ExpiresAtLT applies the LT predicate on the "expires_at" field.
func ExpiresAtLTE ¶
func ExpiresAtLTE(v time.Time) predicate.RoleBinding
ExpiresAtLTE applies the LTE predicate on the "expires_at" field.
func ExpiresAtNEQ ¶
func ExpiresAtNEQ(v time.Time) predicate.RoleBinding
ExpiresAtNEQ applies the NEQ predicate on the "expires_at" field.
func ExpiresAtNotIn ¶
func ExpiresAtNotIn(vs ...time.Time) predicate.RoleBinding
ExpiresAtNotIn applies the NotIn predicate on the "expires_at" field.
func ExpiresAtNotNil ¶
func ExpiresAtNotNil() predicate.RoleBinding
ExpiresAtNotNil applies the NotNil predicate on the "expires_at" field.
func GrantedBy ¶
func GrantedBy(v string) predicate.RoleBinding
GrantedBy applies equality check predicate on the "granted_by" field. It's identical to GrantedByEQ.
func GrantedByContains ¶
func GrantedByContains(v string) predicate.RoleBinding
GrantedByContains applies the Contains predicate on the "granted_by" field.
func GrantedByContainsFold ¶
func GrantedByContainsFold(v string) predicate.RoleBinding
GrantedByContainsFold applies the ContainsFold predicate on the "granted_by" field.
func GrantedByEQ ¶
func GrantedByEQ(v string) predicate.RoleBinding
GrantedByEQ applies the EQ predicate on the "granted_by" field.
func GrantedByEqualFold ¶
func GrantedByEqualFold(v string) predicate.RoleBinding
GrantedByEqualFold applies the EqualFold predicate on the "granted_by" field.
func GrantedByGT ¶
func GrantedByGT(v string) predicate.RoleBinding
GrantedByGT applies the GT predicate on the "granted_by" field.
func GrantedByGTE ¶
func GrantedByGTE(v string) predicate.RoleBinding
GrantedByGTE applies the GTE predicate on the "granted_by" field.
func GrantedByHasPrefix ¶
func GrantedByHasPrefix(v string) predicate.RoleBinding
GrantedByHasPrefix applies the HasPrefix predicate on the "granted_by" field.
func GrantedByHasSuffix ¶
func GrantedByHasSuffix(v string) predicate.RoleBinding
GrantedByHasSuffix applies the HasSuffix predicate on the "granted_by" field.
func GrantedByIn ¶
func GrantedByIn(vs ...string) predicate.RoleBinding
GrantedByIn applies the In predicate on the "granted_by" field.
func GrantedByLT ¶
func GrantedByLT(v string) predicate.RoleBinding
GrantedByLT applies the LT predicate on the "granted_by" field.
func GrantedByLTE ¶
func GrantedByLTE(v string) predicate.RoleBinding
GrantedByLTE applies the LTE predicate on the "granted_by" field.
func GrantedByNEQ ¶
func GrantedByNEQ(v string) predicate.RoleBinding
GrantedByNEQ applies the NEQ predicate on the "granted_by" field.
func GrantedByNotIn ¶
func GrantedByNotIn(vs ...string) predicate.RoleBinding
GrantedByNotIn applies the NotIn predicate on the "granted_by" field.
func IDEQ ¶
func IDEQ(id uuid.UUID) predicate.RoleBinding
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id uuid.UUID) predicate.RoleBinding
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id uuid.UUID) predicate.RoleBinding
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...uuid.UUID) predicate.RoleBinding
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id uuid.UUID) predicate.RoleBinding
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id uuid.UUID) predicate.RoleBinding
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id uuid.UUID) predicate.RoleBinding
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...uuid.UUID) predicate.RoleBinding
IDNotIn applies the NotIn predicate on the ID field.
func Not ¶
func Not(p predicate.RoleBinding) predicate.RoleBinding
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.RoleBinding) predicate.RoleBinding
Or groups predicates with the OR operator between them.
func RoleKey ¶
func RoleKey(v string) predicate.RoleBinding
RoleKey applies equality check predicate on the "role_key" field. It's identical to RoleKeyEQ.
func RoleKeyContains ¶
func RoleKeyContains(v string) predicate.RoleBinding
RoleKeyContains applies the Contains predicate on the "role_key" field.
func RoleKeyContainsFold ¶
func RoleKeyContainsFold(v string) predicate.RoleBinding
RoleKeyContainsFold applies the ContainsFold predicate on the "role_key" field.
func RoleKeyEQ ¶
func RoleKeyEQ(v string) predicate.RoleBinding
RoleKeyEQ applies the EQ predicate on the "role_key" field.
func RoleKeyEqualFold ¶
func RoleKeyEqualFold(v string) predicate.RoleBinding
RoleKeyEqualFold applies the EqualFold predicate on the "role_key" field.
func RoleKeyGT ¶
func RoleKeyGT(v string) predicate.RoleBinding
RoleKeyGT applies the GT predicate on the "role_key" field.
func RoleKeyGTE ¶
func RoleKeyGTE(v string) predicate.RoleBinding
RoleKeyGTE applies the GTE predicate on the "role_key" field.
func RoleKeyHasPrefix ¶
func RoleKeyHasPrefix(v string) predicate.RoleBinding
RoleKeyHasPrefix applies the HasPrefix predicate on the "role_key" field.
func RoleKeyHasSuffix ¶
func RoleKeyHasSuffix(v string) predicate.RoleBinding
RoleKeyHasSuffix applies the HasSuffix predicate on the "role_key" field.
func RoleKeyIn ¶
func RoleKeyIn(vs ...string) predicate.RoleBinding
RoleKeyIn applies the In predicate on the "role_key" field.
func RoleKeyLT ¶
func RoleKeyLT(v string) predicate.RoleBinding
RoleKeyLT applies the LT predicate on the "role_key" field.
func RoleKeyLTE ¶
func RoleKeyLTE(v string) predicate.RoleBinding
RoleKeyLTE applies the LTE predicate on the "role_key" field.
func RoleKeyNEQ ¶
func RoleKeyNEQ(v string) predicate.RoleBinding
RoleKeyNEQ applies the NEQ predicate on the "role_key" field.
func RoleKeyNotIn ¶
func RoleKeyNotIn(vs ...string) predicate.RoleBinding
RoleKeyNotIn applies the NotIn predicate on the "role_key" field.
func ScopeID ¶
func ScopeID(v string) predicate.RoleBinding
ScopeID applies equality check predicate on the "scope_id" field. It's identical to ScopeIDEQ.
func ScopeIDContains ¶
func ScopeIDContains(v string) predicate.RoleBinding
ScopeIDContains applies the Contains predicate on the "scope_id" field.
func ScopeIDContainsFold ¶
func ScopeIDContainsFold(v string) predicate.RoleBinding
ScopeIDContainsFold applies the ContainsFold predicate on the "scope_id" field.
func ScopeIDEQ ¶
func ScopeIDEQ(v string) predicate.RoleBinding
ScopeIDEQ applies the EQ predicate on the "scope_id" field.
func ScopeIDEqualFold ¶
func ScopeIDEqualFold(v string) predicate.RoleBinding
ScopeIDEqualFold applies the EqualFold predicate on the "scope_id" field.
func ScopeIDGT ¶
func ScopeIDGT(v string) predicate.RoleBinding
ScopeIDGT applies the GT predicate on the "scope_id" field.
func ScopeIDGTE ¶
func ScopeIDGTE(v string) predicate.RoleBinding
ScopeIDGTE applies the GTE predicate on the "scope_id" field.
func ScopeIDHasPrefix ¶
func ScopeIDHasPrefix(v string) predicate.RoleBinding
ScopeIDHasPrefix applies the HasPrefix predicate on the "scope_id" field.
func ScopeIDHasSuffix ¶
func ScopeIDHasSuffix(v string) predicate.RoleBinding
ScopeIDHasSuffix applies the HasSuffix predicate on the "scope_id" field.
func ScopeIDIn ¶
func ScopeIDIn(vs ...string) predicate.RoleBinding
ScopeIDIn applies the In predicate on the "scope_id" field.
func ScopeIDLT ¶
func ScopeIDLT(v string) predicate.RoleBinding
ScopeIDLT applies the LT predicate on the "scope_id" field.
func ScopeIDLTE ¶
func ScopeIDLTE(v string) predicate.RoleBinding
ScopeIDLTE applies the LTE predicate on the "scope_id" field.
func ScopeIDNEQ ¶
func ScopeIDNEQ(v string) predicate.RoleBinding
ScopeIDNEQ applies the NEQ predicate on the "scope_id" field.
func ScopeIDNotIn ¶
func ScopeIDNotIn(vs ...string) predicate.RoleBinding
ScopeIDNotIn applies the NotIn predicate on the "scope_id" field.
func ScopeKindEQ ¶
func ScopeKindEQ(v ScopeKind) predicate.RoleBinding
ScopeKindEQ applies the EQ predicate on the "scope_kind" field.
func ScopeKindIn ¶
func ScopeKindIn(vs ...ScopeKind) predicate.RoleBinding
ScopeKindIn applies the In predicate on the "scope_kind" field.
func ScopeKindNEQ ¶
func ScopeKindNEQ(v ScopeKind) predicate.RoleBinding
ScopeKindNEQ applies the NEQ predicate on the "scope_kind" field.
func ScopeKindNotIn ¶
func ScopeKindNotIn(vs ...ScopeKind) predicate.RoleBinding
ScopeKindNotIn applies the NotIn predicate on the "scope_kind" field.
func ScopeKindValidator ¶
ScopeKindValidator is a validator for the "scope_kind" field enum values. It is called by the builders before save.
func SubjectKey ¶
func SubjectKey(v string) predicate.RoleBinding
SubjectKey applies equality check predicate on the "subject_key" field. It's identical to SubjectKeyEQ.
func SubjectKeyContains ¶
func SubjectKeyContains(v string) predicate.RoleBinding
SubjectKeyContains applies the Contains predicate on the "subject_key" field.
func SubjectKeyContainsFold ¶
func SubjectKeyContainsFold(v string) predicate.RoleBinding
SubjectKeyContainsFold applies the ContainsFold predicate on the "subject_key" field.
func SubjectKeyEQ ¶
func SubjectKeyEQ(v string) predicate.RoleBinding
SubjectKeyEQ applies the EQ predicate on the "subject_key" field.
func SubjectKeyEqualFold ¶
func SubjectKeyEqualFold(v string) predicate.RoleBinding
SubjectKeyEqualFold applies the EqualFold predicate on the "subject_key" field.
func SubjectKeyGT ¶
func SubjectKeyGT(v string) predicate.RoleBinding
SubjectKeyGT applies the GT predicate on the "subject_key" field.
func SubjectKeyGTE ¶
func SubjectKeyGTE(v string) predicate.RoleBinding
SubjectKeyGTE applies the GTE predicate on the "subject_key" field.
func SubjectKeyHasPrefix ¶
func SubjectKeyHasPrefix(v string) predicate.RoleBinding
SubjectKeyHasPrefix applies the HasPrefix predicate on the "subject_key" field.
func SubjectKeyHasSuffix ¶
func SubjectKeyHasSuffix(v string) predicate.RoleBinding
SubjectKeyHasSuffix applies the HasSuffix predicate on the "subject_key" field.
func SubjectKeyIn ¶
func SubjectKeyIn(vs ...string) predicate.RoleBinding
SubjectKeyIn applies the In predicate on the "subject_key" field.
func SubjectKeyLT ¶
func SubjectKeyLT(v string) predicate.RoleBinding
SubjectKeyLT applies the LT predicate on the "subject_key" field.
func SubjectKeyLTE ¶
func SubjectKeyLTE(v string) predicate.RoleBinding
SubjectKeyLTE applies the LTE predicate on the "subject_key" field.
func SubjectKeyNEQ ¶
func SubjectKeyNEQ(v string) predicate.RoleBinding
SubjectKeyNEQ applies the NEQ predicate on the "subject_key" field.
func SubjectKeyNotIn ¶
func SubjectKeyNotIn(vs ...string) predicate.RoleBinding
SubjectKeyNotIn applies the NotIn predicate on the "subject_key" field.
func SubjectKindEQ ¶
func SubjectKindEQ(v SubjectKind) predicate.RoleBinding
SubjectKindEQ applies the EQ predicate on the "subject_kind" field.
func SubjectKindIn ¶
func SubjectKindIn(vs ...SubjectKind) predicate.RoleBinding
SubjectKindIn applies the In predicate on the "subject_kind" field.
func SubjectKindNEQ ¶
func SubjectKindNEQ(v SubjectKind) predicate.RoleBinding
SubjectKindNEQ applies the NEQ predicate on the "subject_kind" field.
func SubjectKindNotIn ¶
func SubjectKindNotIn(vs ...SubjectKind) predicate.RoleBinding
SubjectKindNotIn applies the NotIn predicate on the "subject_kind" field.
func SubjectKindValidator ¶
func SubjectKindValidator(sk SubjectKind) error
SubjectKindValidator is a validator for the "subject_kind" field enum values. It is called by the builders before save.
func UpdatedAt ¶
func UpdatedAt(v time.Time) predicate.RoleBinding
UpdatedAt applies equality check predicate on the "updated_at" field. It's identical to UpdatedAtEQ.
func UpdatedAtEQ ¶
func UpdatedAtEQ(v time.Time) predicate.RoleBinding
UpdatedAtEQ applies the EQ predicate on the "updated_at" field.
func UpdatedAtGT ¶
func UpdatedAtGT(v time.Time) predicate.RoleBinding
UpdatedAtGT applies the GT predicate on the "updated_at" field.
func UpdatedAtGTE ¶
func UpdatedAtGTE(v time.Time) predicate.RoleBinding
UpdatedAtGTE applies the GTE predicate on the "updated_at" field.
func UpdatedAtIn ¶
func UpdatedAtIn(vs ...time.Time) predicate.RoleBinding
UpdatedAtIn applies the In predicate on the "updated_at" field.
func UpdatedAtLT ¶
func UpdatedAtLT(v time.Time) predicate.RoleBinding
UpdatedAtLT applies the LT predicate on the "updated_at" field.
func UpdatedAtLTE ¶
func UpdatedAtLTE(v time.Time) predicate.RoleBinding
UpdatedAtLTE applies the LTE predicate on the "updated_at" field.
func UpdatedAtNEQ ¶
func UpdatedAtNEQ(v time.Time) predicate.RoleBinding
UpdatedAtNEQ applies the NEQ predicate on the "updated_at" field.
func UpdatedAtNotIn ¶
func UpdatedAtNotIn(vs ...time.Time) predicate.RoleBinding
UpdatedAtNotIn applies the NotIn predicate on the "updated_at" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the RoleBinding queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByExpiresAt ¶
func ByExpiresAt(opts ...sql.OrderTermOption) OrderOption
ByExpiresAt orders the results by the expires_at field.
func ByGrantedBy ¶
func ByGrantedBy(opts ...sql.OrderTermOption) OrderOption
ByGrantedBy orders the results by the granted_by field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByRoleKey ¶
func ByRoleKey(opts ...sql.OrderTermOption) OrderOption
ByRoleKey orders the results by the role_key field.
func ByScopeID ¶
func ByScopeID(opts ...sql.OrderTermOption) OrderOption
ByScopeID orders the results by the scope_id field.
func ByScopeKind ¶
func ByScopeKind(opts ...sql.OrderTermOption) OrderOption
ByScopeKind orders the results by the scope_kind field.
func BySubjectKey ¶
func BySubjectKey(opts ...sql.OrderTermOption) OrderOption
BySubjectKey orders the results by the subject_key field.
func BySubjectKind ¶
func BySubjectKind(opts ...sql.OrderTermOption) OrderOption
BySubjectKind orders the results by the subject_kind field.
func ByUpdatedAt ¶
func ByUpdatedAt(opts ...sql.OrderTermOption) OrderOption
ByUpdatedAt orders the results by the updated_at field.
type ScopeKind ¶
type ScopeKind string
ScopeKind defines the type for the "scope_kind" enum field.
type SubjectKind ¶
type SubjectKind string
SubjectKind defines the type for the "subject_kind" enum field.
const ( SubjectKindUser SubjectKind = "user" SubjectKindGroup SubjectKind = "group" )
SubjectKind values.
func (SubjectKind) String ¶
func (sk SubjectKind) String() string