Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.WorkflowSkillBinding) predicate.WorkflowSkillBinding
- func CreatedAt(v time.Time) predicate.WorkflowSkillBinding
- func CreatedAtEQ(v time.Time) predicate.WorkflowSkillBinding
- func CreatedAtGT(v time.Time) predicate.WorkflowSkillBinding
- func CreatedAtGTE(v time.Time) predicate.WorkflowSkillBinding
- func CreatedAtIn(vs ...time.Time) predicate.WorkflowSkillBinding
- func CreatedAtLT(v time.Time) predicate.WorkflowSkillBinding
- func CreatedAtLTE(v time.Time) predicate.WorkflowSkillBinding
- func CreatedAtNEQ(v time.Time) predicate.WorkflowSkillBinding
- func CreatedAtNotIn(vs ...time.Time) predicate.WorkflowSkillBinding
- func HasRequiredVersion() predicate.WorkflowSkillBinding
- func HasRequiredVersionWith(preds ...predicate.SkillVersion) predicate.WorkflowSkillBinding
- func HasSkill() predicate.WorkflowSkillBinding
- func HasSkillWith(preds ...predicate.Skill) predicate.WorkflowSkillBinding
- func HasWorkflow() predicate.WorkflowSkillBinding
- func HasWorkflowWith(preds ...predicate.Workflow) predicate.WorkflowSkillBinding
- func ID(id uuid.UUID) predicate.WorkflowSkillBinding
- func IDEQ(id uuid.UUID) predicate.WorkflowSkillBinding
- func IDGT(id uuid.UUID) predicate.WorkflowSkillBinding
- func IDGTE(id uuid.UUID) predicate.WorkflowSkillBinding
- func IDIn(ids ...uuid.UUID) predicate.WorkflowSkillBinding
- func IDLT(id uuid.UUID) predicate.WorkflowSkillBinding
- func IDLTE(id uuid.UUID) predicate.WorkflowSkillBinding
- func IDNEQ(id uuid.UUID) predicate.WorkflowSkillBinding
- func IDNotIn(ids ...uuid.UUID) predicate.WorkflowSkillBinding
- func Not(p predicate.WorkflowSkillBinding) predicate.WorkflowSkillBinding
- func Or(predicates ...predicate.WorkflowSkillBinding) predicate.WorkflowSkillBinding
- func RequiredVersionID(v uuid.UUID) predicate.WorkflowSkillBinding
- func RequiredVersionIDEQ(v uuid.UUID) predicate.WorkflowSkillBinding
- func RequiredVersionIDIn(vs ...uuid.UUID) predicate.WorkflowSkillBinding
- func RequiredVersionIDIsNil() predicate.WorkflowSkillBinding
- func RequiredVersionIDNEQ(v uuid.UUID) predicate.WorkflowSkillBinding
- func RequiredVersionIDNotIn(vs ...uuid.UUID) predicate.WorkflowSkillBinding
- func RequiredVersionIDNotNil() predicate.WorkflowSkillBinding
- func SkillID(v uuid.UUID) predicate.WorkflowSkillBinding
- func SkillIDEQ(v uuid.UUID) predicate.WorkflowSkillBinding
- func SkillIDIn(vs ...uuid.UUID) predicate.WorkflowSkillBinding
- func SkillIDNEQ(v uuid.UUID) predicate.WorkflowSkillBinding
- func SkillIDNotIn(vs ...uuid.UUID) predicate.WorkflowSkillBinding
- func ValidColumn(column string) bool
- func WorkflowID(v uuid.UUID) predicate.WorkflowSkillBinding
- func WorkflowIDEQ(v uuid.UUID) predicate.WorkflowSkillBinding
- func WorkflowIDIn(vs ...uuid.UUID) predicate.WorkflowSkillBinding
- func WorkflowIDNEQ(v uuid.UUID) predicate.WorkflowSkillBinding
- func WorkflowIDNotIn(vs ...uuid.UUID) predicate.WorkflowSkillBinding
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByRequiredVersionField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByRequiredVersionID(opts ...sql.OrderTermOption) OrderOption
- func BySkillField(field string, opts ...sql.OrderTermOption) OrderOption
- func BySkillID(opts ...sql.OrderTermOption) OrderOption
- func ByWorkflowField(field string, opts ...sql.OrderTermOption) OrderOption
- func ByWorkflowID(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the workflowskillbinding type in the database. Label = "workflow_skill_binding" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldWorkflowID holds the string denoting the workflow_id field in the database. FieldWorkflowID = "workflow_id" // FieldSkillID holds the string denoting the skill_id field in the database. FieldSkillID = "skill_id" // FieldRequiredVersionID holds the string denoting the required_version_id field in the database. FieldRequiredVersionID = "required_version_id" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // EdgeWorkflow holds the string denoting the workflow edge name in mutations. EdgeWorkflow = "workflow" // EdgeSkill holds the string denoting the skill edge name in mutations. EdgeSkill = "skill" // EdgeRequiredVersion holds the string denoting the required_version edge name in mutations. EdgeRequiredVersion = "required_version" // Table holds the table name of the workflowskillbinding in the database. Table = "workflow_skill_bindings" // WorkflowTable is the table that holds the workflow relation/edge. WorkflowTable = "workflow_skill_bindings" // WorkflowInverseTable is the table name for the Workflow entity. // It exists in this package in order to avoid circular dependency with the "workflow" package. WorkflowInverseTable = "workflows" // WorkflowColumn is the table column denoting the workflow relation/edge. WorkflowColumn = "workflow_id" // SkillTable is the table that holds the skill relation/edge. SkillTable = "workflow_skill_bindings" // SkillInverseTable is the table name for the Skill entity. // It exists in this package in order to avoid circular dependency with the "skill" package. SkillInverseTable = "skills" // SkillColumn is the table column denoting the skill relation/edge. SkillColumn = "skill_id" // RequiredVersionTable is the table that holds the required_version relation/edge. RequiredVersionTable = "workflow_skill_bindings" // RequiredVersionInverseTable is the table name for the SkillVersion entity. // It exists in this package in order to avoid circular dependency with the "skillversion" package. RequiredVersionInverseTable = "skill_versions" // RequiredVersionColumn is the table column denoting the required_version relation/edge. RequiredVersionColumn = "required_version_id" )
Variables ¶
var ( // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultID holds the default value on creation for the "id" field. DefaultID func() uuid.UUID )
var Columns = []string{ FieldID, FieldWorkflowID, FieldSkillID, FieldRequiredVersionID, FieldCreatedAt, }
Columns holds all SQL columns for workflowskillbinding fields.
Functions ¶
func And ¶
func And(predicates ...predicate.WorkflowSkillBinding) predicate.WorkflowSkillBinding
And groups predicates with the AND operator between them.
func CreatedAt ¶
func CreatedAt(v time.Time) predicate.WorkflowSkillBinding
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
func CreatedAtEQ(v time.Time) predicate.WorkflowSkillBinding
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
func CreatedAtGT(v time.Time) predicate.WorkflowSkillBinding
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
func CreatedAtGTE(v time.Time) predicate.WorkflowSkillBinding
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
func CreatedAtIn(vs ...time.Time) predicate.WorkflowSkillBinding
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
func CreatedAtLT(v time.Time) predicate.WorkflowSkillBinding
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
func CreatedAtLTE(v time.Time) predicate.WorkflowSkillBinding
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
func CreatedAtNEQ(v time.Time) predicate.WorkflowSkillBinding
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
func CreatedAtNotIn(vs ...time.Time) predicate.WorkflowSkillBinding
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func HasRequiredVersion ¶
func HasRequiredVersion() predicate.WorkflowSkillBinding
HasRequiredVersion applies the HasEdge predicate on the "required_version" edge.
func HasRequiredVersionWith ¶
func HasRequiredVersionWith(preds ...predicate.SkillVersion) predicate.WorkflowSkillBinding
HasRequiredVersionWith applies the HasEdge predicate on the "required_version" edge with a given conditions (other predicates).
func HasSkill ¶
func HasSkill() predicate.WorkflowSkillBinding
HasSkill applies the HasEdge predicate on the "skill" edge.
func HasSkillWith ¶
func HasSkillWith(preds ...predicate.Skill) predicate.WorkflowSkillBinding
HasSkillWith applies the HasEdge predicate on the "skill" edge with a given conditions (other predicates).
func HasWorkflow ¶
func HasWorkflow() predicate.WorkflowSkillBinding
HasWorkflow applies the HasEdge predicate on the "workflow" edge.
func HasWorkflowWith ¶
func HasWorkflowWith(preds ...predicate.Workflow) predicate.WorkflowSkillBinding
HasWorkflowWith applies the HasEdge predicate on the "workflow" edge with a given conditions (other predicates).
func ID ¶
func ID(id uuid.UUID) predicate.WorkflowSkillBinding
ID filters vertices based on their ID field.
func IDEQ ¶
func IDEQ(id uuid.UUID) predicate.WorkflowSkillBinding
IDEQ applies the EQ predicate on the ID field.
func IDGT ¶
func IDGT(id uuid.UUID) predicate.WorkflowSkillBinding
IDGT applies the GT predicate on the ID field.
func IDGTE ¶
func IDGTE(id uuid.UUID) predicate.WorkflowSkillBinding
IDGTE applies the GTE predicate on the ID field.
func IDIn ¶
func IDIn(ids ...uuid.UUID) predicate.WorkflowSkillBinding
IDIn applies the In predicate on the ID field.
func IDLT ¶
func IDLT(id uuid.UUID) predicate.WorkflowSkillBinding
IDLT applies the LT predicate on the ID field.
func IDLTE ¶
func IDLTE(id uuid.UUID) predicate.WorkflowSkillBinding
IDLTE applies the LTE predicate on the ID field.
func IDNEQ ¶
func IDNEQ(id uuid.UUID) predicate.WorkflowSkillBinding
IDNEQ applies the NEQ predicate on the ID field.
func IDNotIn ¶
func IDNotIn(ids ...uuid.UUID) predicate.WorkflowSkillBinding
IDNotIn applies the NotIn predicate on the ID field.
func Not ¶
func Not(p predicate.WorkflowSkillBinding) predicate.WorkflowSkillBinding
Not applies the not operator on the given predicate.
func Or ¶
func Or(predicates ...predicate.WorkflowSkillBinding) predicate.WorkflowSkillBinding
Or groups predicates with the OR operator between them.
func RequiredVersionID ¶
func RequiredVersionID(v uuid.UUID) predicate.WorkflowSkillBinding
RequiredVersionID applies equality check predicate on the "required_version_id" field. It's identical to RequiredVersionIDEQ.
func RequiredVersionIDEQ ¶
func RequiredVersionIDEQ(v uuid.UUID) predicate.WorkflowSkillBinding
RequiredVersionIDEQ applies the EQ predicate on the "required_version_id" field.
func RequiredVersionIDIn ¶
func RequiredVersionIDIn(vs ...uuid.UUID) predicate.WorkflowSkillBinding
RequiredVersionIDIn applies the In predicate on the "required_version_id" field.
func RequiredVersionIDIsNil ¶
func RequiredVersionIDIsNil() predicate.WorkflowSkillBinding
RequiredVersionIDIsNil applies the IsNil predicate on the "required_version_id" field.
func RequiredVersionIDNEQ ¶
func RequiredVersionIDNEQ(v uuid.UUID) predicate.WorkflowSkillBinding
RequiredVersionIDNEQ applies the NEQ predicate on the "required_version_id" field.
func RequiredVersionIDNotIn ¶
func RequiredVersionIDNotIn(vs ...uuid.UUID) predicate.WorkflowSkillBinding
RequiredVersionIDNotIn applies the NotIn predicate on the "required_version_id" field.
func RequiredVersionIDNotNil ¶
func RequiredVersionIDNotNil() predicate.WorkflowSkillBinding
RequiredVersionIDNotNil applies the NotNil predicate on the "required_version_id" field.
func SkillID ¶
func SkillID(v uuid.UUID) predicate.WorkflowSkillBinding
SkillID applies equality check predicate on the "skill_id" field. It's identical to SkillIDEQ.
func SkillIDEQ ¶
func SkillIDEQ(v uuid.UUID) predicate.WorkflowSkillBinding
SkillIDEQ applies the EQ predicate on the "skill_id" field.
func SkillIDIn ¶
func SkillIDIn(vs ...uuid.UUID) predicate.WorkflowSkillBinding
SkillIDIn applies the In predicate on the "skill_id" field.
func SkillIDNEQ ¶
func SkillIDNEQ(v uuid.UUID) predicate.WorkflowSkillBinding
SkillIDNEQ applies the NEQ predicate on the "skill_id" field.
func SkillIDNotIn ¶
func SkillIDNotIn(vs ...uuid.UUID) predicate.WorkflowSkillBinding
SkillIDNotIn applies the NotIn predicate on the "skill_id" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
func WorkflowID ¶
func WorkflowID(v uuid.UUID) predicate.WorkflowSkillBinding
WorkflowID applies equality check predicate on the "workflow_id" field. It's identical to WorkflowIDEQ.
func WorkflowIDEQ ¶
func WorkflowIDEQ(v uuid.UUID) predicate.WorkflowSkillBinding
WorkflowIDEQ applies the EQ predicate on the "workflow_id" field.
func WorkflowIDIn ¶
func WorkflowIDIn(vs ...uuid.UUID) predicate.WorkflowSkillBinding
WorkflowIDIn applies the In predicate on the "workflow_id" field.
func WorkflowIDNEQ ¶
func WorkflowIDNEQ(v uuid.UUID) predicate.WorkflowSkillBinding
WorkflowIDNEQ applies the NEQ predicate on the "workflow_id" field.
func WorkflowIDNotIn ¶
func WorkflowIDNotIn(vs ...uuid.UUID) predicate.WorkflowSkillBinding
WorkflowIDNotIn applies the NotIn predicate on the "workflow_id" field.
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the WorkflowSkillBinding queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByRequiredVersionField ¶
func ByRequiredVersionField(field string, opts ...sql.OrderTermOption) OrderOption
ByRequiredVersionField orders the results by required_version field.
func ByRequiredVersionID ¶
func ByRequiredVersionID(opts ...sql.OrderTermOption) OrderOption
ByRequiredVersionID orders the results by the required_version_id field.
func BySkillField ¶
func BySkillField(field string, opts ...sql.OrderTermOption) OrderOption
BySkillField orders the results by skill field.
func BySkillID ¶
func BySkillID(opts ...sql.OrderTermOption) OrderOption
BySkillID orders the results by the skill_id field.
func ByWorkflowField ¶
func ByWorkflowField(field string, opts ...sql.OrderTermOption) OrderOption
ByWorkflowField orders the results by workflow field.
func ByWorkflowID ¶
func ByWorkflowID(opts ...sql.OrderTermOption) OrderOption
ByWorkflowID orders the results by the workflow_id field.